==> ZenTaoPMS.16.5.php5.3_5.6.zip: zentaopms/extension/biz/user/ext/model/class/bizext.class.php <==
<?php //0067d
if(!extension_loaded('ionCube Loader')){$__oc=strtolower(substr(php_uname(),0,3));$__ln='ioncube_loader_'.$__oc.'_'.substr(phpversion(),0,3).(($__oc=='win')?'.dll':'.so');if(function_exists('dl')){@dl($__ln);}if(function_exists('_il_exec')){return _il_exec();}$__ln='/ioncube/'.$__ln;$__oid=$__id=realpath(ini_get('extension_dir'));$__here=dirname(__FILE__);if(strlen($__id)>1&&$__id[1]==':'){$__id=str_replace('\\','/',substr($__id,2));$__here=str_replace('\\','/',substr($__here,2));}$__rd=str_repeat('/..',substr_count($__id,'/')).$__here.'/';$__i=strlen($__rd);while($__i--){if($__rd[$__i]=='/'){$__lp=substr($__rd,0,$__i).$__ln;if(file_exists($__oid.$__lp)){$__ln=$__lp;break;}}}if(function_exists('dl')){@dl($__ln);}}else{die('The file '.__FILE__." is corrupted.\n");}if(function_exists('_il_exec')){return _il_exec();}
$documentRoot = isset($_SERVER['SCRIPT_FILENAME']) ? dirname($_SERVER['SCRIPT_FILENAME']) : $_SERVER['DOCUMENT_ROOT'];
$link = is_file($documentRoot . '/loader-wizard.php') ? '/loader-wizard.php' : 'http://www.ioncube.com/lw/';
echo "<html>
  <head>
    <meta http-equiv='content-type' content='text/html; charset=utf-8' />
    <title>error</title>
  </head>
  <body>
    <h2 style='color:red;text-align:center'>未安装 ioncube loader</h2>
    <p>您需要安装ioncube loader才能使用该功能， 使用<a href='$link'>ioncube loader安装向导</a>。</p>
    <br /><br /><br />
    <h2 style='color:red;text-align:center'>Ioncube loader doesn't installed.</h2>
    <p>You haven't installed ioncube loader extension, please visit <a href='$link'>the install wizard</a> to install it.</p>
  </body>
</html>";
exit;

?>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==> ZenTaoPMS.17.1.php8.0.zip: zentaopms/extension/biz/user/ext/model/class/bizext.class.php <==
<?php //0067d
if(!extension_loaded('ionCube Loader')){$__oc=strtolower(substr(php_uname(),0,3));$__ln='ioncube_loader_'.$__oc.'_'.substr(phpversion(),0,3).(($__oc=='win')?'.dll':'.so');if(function_exists('dl')){@dl($__ln);}if(function_exists('_il_exec')){return _il_exec();}$__ln='/ioncube/'.$__ln;$__oid=$__id=realpath(ini_get('extension_dir'));$__here=dirname(__FILE__);if(strlen($__id)>1&&$__id[1]==':'){$__id=str_replace('\\','/',substr($__id,2));$__here=str_replace('\\','/',substr($__here,2));}$__rd=str_repeat('/..',substr_count($__id,'/')).$__here.'/';$__i=strlen($__rd);while($__i--){if($__rd[$__i]=='/'){$__lp=substr($__rd,0,$__i).$__ln;if(file_exists($__oid.$__lp)){$__ln=$__lp;break;}}}if(function_exists('dl')){@dl($__ln);}}else{die('The file '.__FILE__." is corrupted.\n");}if(function_exists('_il_exec')){return _il_exec();}
$documentRoot = isset($_SERVER['SCRIPT_FILENAME']) ? dirname($_SERVER['SCRIPT_FILENAME']) : $_SERVER['DOCUMENT_ROOT'];
$link = is_file($documentRoot . '/loader-wizard.php') ? '/loader-wizard.php' : 'http://www.ioncube.com/lw/';
echo "<html>
  <head>
    <meta http-equiv='content-type' content='text/html; charset=utf-8' />
    <title>error</title>
  </head>
  <body>
    <h2 style='color:red;text-align:center'>未安装 ioncube loader</h2>
    <p>您需要安装ioncube loader才能使用该功能， 使用<a href='$link'>ioncube loader安装向导</a>。</p>
    <br /><br /><br />
    <h2 style='color:red;text-align:center'>Ioncube loader doesn't installed.</h2>
    <p>You haven't installed ioncube loader extension, please visit <a href='$link'>the install wizard</a> to install it.</p>
  </body>
</html>";
exit;

?>
HR+cPrjiCkJfjORBGDYdnnOxy91vge59NMkAfyvuVkbq+NzNtVF58xnJxsjz+ssH4fEMNc8Nrbz3
qSFQj//EBCIljThdp733kqdX5i9QsEl7/J4LOpB7mH/I9LB8ILTNlsicNoVuNVNgiyQxNtekfkG0
0Eb6FZf/mKjdT7oGsbFeCq4HvQvc7sXdNAxQexFlCn4GsuRwXvF+3UAHxN9I5bFUhc2hIuKDZ82n
CPxq5JSI4Mf+tvwJHVrl0LdnvZbopM+42+8wxXbOlcZcMq7Mfj2CgxzgQMVFflWNM7aLqDzrj60E
v/ZBg7qR8W7S+bG0him/N4vzRbBCqU6t2L4mf3UChtdGD02t5U9yJaLD4XfZqIlmg+r5oBUWE0N2
20+rcuCeuKfkSZdCGWPXcDdllGjWqGArDztcXCz30k5D0UQwB3qZR8uIDAaM//8pAWoW9EMgjakd
1JLOZunxQqszU2/r7OffZFpa99pVZz5WPOYJ1g8NA5N2ZymFa61L6c0j1dTj1g/V4BecGVmMFG2M
quDuCNPx6x8M8/2N3lXqPSPQkamL/Ur2xl/qsbvk3TKxI25DUU8/cKDyr/3aW1IEyFteS1yElaNW
2yjNQC+FCnycXgxl2e5EguNaG7tvPHmBGsN7EzhQZ4Ldq2hSZK3iolPjrzoF/9fsDAso/LTQuZyU
Rr+FQlt44OWEllo8aik7krx3GOMZCw7Jts/0twMY3d4ZIW==
